import React from 'react';
import { View, StyleSheet, TouchableOpacity, Image } from 'react-native';
import { Ionicons } from '@expo/vector-icons';
import StrongText from '../components/StrongText';

const LinkButton = (props) => {
	return (
		<TouchableOpacity style={styles.linkContainer} onPress={props.onSelect}>
			<View style={styles.imageContainer}>
				<Image
					source={props.image}
					style={styles.image}
					width={15}
					height={15}
				/>
			</View>
			<View style={styles.textContainer}>
				<StrongText numberOfLines={2} style={{ color: props.color }}>
					{props.title}
				</StrongText>
			</View>
			<View style={styles.iconContainer}>
				<Ionicons
					name="ios-chevron-forward-sharp"
					size={20}
					color={props.color}
					style={styles.icon}
				/>
			</View>
		</TouchableOpacity>
	);
};

const styles = StyleSheet.create({
	linkContainer: {
		flexDirection: 'row',
		justifyContent: 'space-around',
		shadowColor: 'black',
		shadowOpacity: 0.5,
		shadowOffset: { width: 0, height: 2 },
		shadowRadius: 10,
		elevation: 3,
		backgroundColor: 'white',
		padding: 10,
		marginVertical: 5,
		marginHorizontal: 5,
	},
	imageContainer: { paddingRight: 10 },
	image: { width: 50, height: 50 },
	textContainer: {
		flex: 1,
		justifyContent: 'center',
		alignItems: 'flex-start',
	},
	iconContainer: {
		justifyContent: 'center',
	},
});

export default LinkButton;
