import React, { useState } from 'react';
import { View, StyleSheet, Dimensions, Alert } from 'react-native';
import MapView from 'react-native-maps';
import CustomGeojson from '../components/CustomGeojson';
import {
	CAMPUS_ENTRANCES_BLUE,
	CAMPUS_ENTRANCES_GREEN,
	CAMPUS_ENTRANCES_RED,
} from '../data/geodata/parkings/campus-entrances';
import { EMPLOYEE_ENTRANCES } from '../data/geodata/parkings/employee-entrances';
import { SPECIAL_ACCESS_ZONE } from '../data/geodata/parkings/special-access-zone';
import { SPECIAL_ZONE_ENTRANCES } from '../data/geodata/parkings/special-zone-entrances';
import { STAFF_PARKING } from '../data/geodata/parkings/staff-parking';
import { STUDENT_PARKING } from '../data/geodata/parkings/student-parking';

const ParkingsMap = (props) => {
	const [mapRegion, setMapRegion] = useState({
		latitude: 50.130398,
		longitude: 14.37491,
		latitudeDelta: 0.015,
		longitudeDelta: 0.015,
	});

	const mapStyle = [
		{
			featureType: 'administrative',
			elementType: 'geometry',
			stylers: [
				{
					visibility: 'off',
				},
			],
		},
		{
			featureType: 'poi',
			stylers: [
				{
					visibility: 'off',
				},
			],
		},
		{
			featureType: 'road',
			elementType: 'labels.icon',
			stylers: [
				{
					visibility: 'off',
				},
			],
		},
		{
			featureType: 'transit',
			stylers: [
				{
					visibility: 'off',
				},
			],
		},
	];

	const handlePress = (overlay) => {
		const { Name, description } = overlay.feature.properties;

		Alert.alert(Name, description, [{ text: 'OK', onPress: () => {} }], {
			cancelable: true,
		});
	};

	return (
		<View style={styles.container}>
			<MapView
				style={styles.map}
				region={mapRegion}
				customMapStyle={mapStyle}
				tappable={true}
			>
				<CustomGeojson
					geojson={CAMPUS_ENTRANCES_BLUE}
					strokeColor="white"
					fillColor="#097138"
					strokeWidth={1}
					image={require('../assets/images/map/car-blue.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={CAMPUS_ENTRANCES_GREEN}
					strokeColor="white"
					fillColor="#097138"
					strokeWidth={1}
					image={require('../assets/images/map/car-green.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={CAMPUS_ENTRANCES_RED}
					strokeColor="white"
					fillColor="#097138"
					strokeWidth={1}
					image={require('../assets/images/map/car-red.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={EMPLOYEE_ENTRANCES}
					strokeColor="white"
					strokeWidth={1}
					image={require('../assets/images/map/entrance-blue.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={SPECIAL_ACCESS_ZONE}
					strokeColor="white"
					fillColor="rgba(165,39,20, 0.5)"
					strokeWidth={1}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={SPECIAL_ZONE_ENTRANCES}
					strokeColor="white"
					strokeWidth={1}
					image={require('../assets/images/map/entrance-red.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={STAFF_PARKING}
					strokeColor="white"
					fillColor="rgba(161,194,250,0.5)"
					strokeWidth={1}
					image={require('../assets/images/map/parking-blue.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={STUDENT_PARKING}
					strokeColor="white"
					fillColor="rgba(124,179,66,0.5)"
					strokeWidth={1}
					image={require('../assets/images/map/parking-green.png')}
					tappable={true}
					onPress={handlePress}
				/>
			</MapView>
		</View>
	);
};

const styles = StyleSheet.create({
	container: {
		flex: 1,
		backgroundColor: '#fff',
		alignItems: 'center',
		justifyContent: 'center',
	},
	map: {
		width: Dimensions.get('window').width,
		height: Dimensions.get('window').height,
	},
});

export default ParkingsMap;
