import React from 'react';
import { Text } from 'react-native';
import { createStackNavigator } from 'react-navigation-stack';
import { createAppContainer } from 'react-navigation';
import { createDrawerNavigator } from 'react-navigation-drawer';
import { Ionicons } from '@expo/vector-icons';
import { createMaterialBottomTabNavigator } from 'react-navigation-material-bottom-tabs';
import CategoriesScreen from '../screens/CategoriesScreen';
import AboutScreen from '../screens/AboutScreen';
import Colors from '../constants/Colors';
import ForewordScreen from '../screens/ForewordScreen';
import WhoWeAreScreen from '../screens/WhoWeAreScreen';
import CampusMapScreen from '../screens/CampusMapScreen';
import ContactsScreen from '../screens/ContactsScreen';
import PracticalInformationScreen from '../screens/practical/PracticalInformationScreen';
import LeisureScreen from '../screens/leisure/LeisureScreen';
import CareerCenterScreen from '../screens/CareerCenterScreen';
import PhysicalEducationScreen from '../screens/leisure/PhysicalEducationScreen';
import StudentAssociationsScreen from '../screens/leisure/StudentAssociationsScreen';
import UniversityPremisesScreen from '../screens/practical/UniversityPremisesScreen';
import ParkingScreen from '../screens/practical/ParkingScreen';
import InternetConnectionScreen from '../screens/practical/InternetConnectionScreen';
import ElectronicWalletScreen from '../screens/practical/ElectronicWalletScreen';
import StudentIdScreen from '../screens/practical/StudentIdScreen';
import MealsScreen from '../screens/practical/MealsScreen';
import HousingScreen from '../screens/practical/HousingScreen';
import InsuranceScreen from '../screens/practical/InsuranceScreen';
import StudyInformationScreen from '../screens/study/StudyInformationScreen';
import InformationSystemsScreen from '../screens/study/InformationSystemsScreen';
import StudyAbroadScreen from '../screens/study/StudyAbroadScreen';
import ScholarshipsScreen from '../screens/study/ScholarshipsScreen';
import ImportantRegulationsScreen from '../screens/study/ImportantRegulationsScreen';
import AcademicYearScreen from '../screens/study/AcademicYearScreen';
import SecurityScreen from '../screens/study/SecurityScreen';
import LibraryScreen from '../screens/study/LibraryScreen';
import TextbooksScreen from '../screens/study/TextbooksScreen';
import EshopScreen from '../screens/study/EshopScreen';
import ShopScreen from '../screens/study/ShopScreen';
import FacultiesScreen from '../screens/faculties/FacultiesScreen';
import EconomicsAndManagementScreen from '../screens/faculties/EconomicsAndManagementScreen';
import AgrobiologyScreen from '../screens/faculties/AgrobiologyScreen';
import EngineeringScreen from '../screens/faculties/EngineeringScreen';
import EnvironmentalSciencesScreen from '../screens/faculties/EnvironmentalSciencesScreen';
import ForestryScreen from '../screens/faculties/ForestryScreen';
import TropicalAgriSciencesScreen from '../screens/faculties/TropicalAgriSciencesScreen';
import InstituteScreen from '../screens/faculties/InstituteScreen';

const defaultStackNavOptions = {
	headerStyle: {
		backgroundColor: Colors.primaryColor,
	},
	headerTintColor: 'white',
	headerTitle: 'A Screen',
};

const CategoriesNavigator = createStackNavigator(
	{
		Categories: CategoriesScreen,
		Foreword: ForewordScreen,
		WhoWeAre: WhoWeAreScreen,
		StudyInformation: StudyInformationScreen,
		Leisure: LeisureScreen,
		Faculties: FacultiesScreen,
		CareerCenter: CareerCenterScreen,
		PhysicalEducation: PhysicalEducationScreen,
		StudentAssociations: StudentAssociationsScreen,
		PracticalInformation: PracticalInformationScreen,
		UniversityPremises: UniversityPremisesScreen,
		Parking: ParkingScreen,
		InternetConnection: InternetConnectionScreen,
		ElectronicWallet: ElectronicWalletScreen,
		StudentId: StudentIdScreen,
		Meals: MealsScreen,
		Housing: HousingScreen,
		Insurance: InsuranceScreen,
		AcademicYear: AcademicYearScreen,
		ImportantRegulations: ImportantRegulationsScreen,
		StudyAbroad: StudyAbroadScreen,
		Scholarships: ScholarshipsScreen,
		InformationSystems: InformationSystemsScreen,
		Security: SecurityScreen,
		Library: LibraryScreen,
		Textbooks: TextbooksScreen,
		Eshop: EshopScreen,
		Shop: ShopScreen,
		EconomicsAndManagement: EconomicsAndManagementScreen,
		Agrobiology: AgrobiologyScreen,
		Engineering: EngineeringScreen,
		EnvironmentalSciences: EnvironmentalSciencesScreen,
		Forestry: ForestryScreen,
		TropicalAgriSciences: TropicalAgriSciencesScreen,
		Institute: InstituteScreen,
	},
	{
		defaultNavigationOptions: defaultStackNavOptions,
	}
);

const ContactsNavigator = createStackNavigator(
	{
		Contacts: ContactsScreen,
	},
	{
		defaultNavigationOptions: defaultStackNavOptions,
	}
);

const CampusMapNavigator = createStackNavigator(
	{
		CampusMap: CampusMapScreen,
	},
	{
		defaultNavigationOptions: defaultStackNavOptions,
	}
);

const tabScreenConfig = {
	Home: {
		screen: CategoriesNavigator,
		navigationOptions: {
			tabBarIcon: (tabInfo) => {
				return (
					<Ionicons name="ios-home-outline" size={25} color="white" />
				);
			},
			tabBarColor: Colors.primaryColor,
			tabBarLabel: <Text style={{ color: 'white' }}>Home</Text>,
		},
	},
	Maps: {
		screen: CampusMapNavigator,
		navigationOptions: {
			tabBarIcon: (tabInfo) => {
				return (
					<Ionicons
						name="ios-location-outline"
						size={25}
						color="white"
					/>
				);
			},
			tabBarColor: Colors.primaryColor,
			tabBarLabel: <Text style={{ color: 'white' }}>Campus Map</Text>,
		},
	},
	Contacts: {
		screen: ContactsNavigator,
		navigationOptions: {
			tabBarIcon: (tabInfo) => {
				return (
					<Ionicons name="ios-call-outline" size={25} color="white" />
				);
			},
			tabBarColor: Colors.primaryColor,
			tabBarLabel: <Text style={{ color: 'white' }}>Contacts</Text>,
		},
	},
};

const BottomTabNavigator = createMaterialBottomTabNavigator(tabScreenConfig, {
	activeTintColor: Colors.accentColor,
	shifting: true,
	barStyle: {
		backgroundColor: Colors.primaryColor,
	},
});

const SideNavigator = createStackNavigator(
	{
		About: AboutScreen,
	},
	{
		defaultNavigationOptions: defaultStackNavOptions,
	}
);

const MainNavigator = createDrawerNavigator(
	{
		Home: {
			screen: BottomTabNavigator,
			navigationOptions: {
				drawerLabel: 'Home',
			},
		},
		About: SideNavigator,
	},
	{
		contentOptions: {
			activeTintColor: Colors.accentColor,
		},
	}
);

export default createAppContainer(MainNavigator);
