import React, { useState, useEffect, useCallback } from 'react';
import { View, StyleSheet } from 'react-native';
import { HeaderButtons, Item } from 'react-navigation-header-buttons';

import HeaderButton from '../components/HeaderButton';
import BuildingsMap from '../components/BuildingsMap';
import ParkingsMap from '../components/ParkingsMap';

const CampusMapScreen = (props) => {
	const { navigation } = props;
	const [isParkingMap, setIsParkingMap] = useState(false);

	const toggleMap = useCallback(() => {
		setIsParkingMap(!isParkingMap);
	}, [isParkingMap]);

	useEffect(() => {
		navigation.setParams({ changeMap: toggleMap });
	}, [toggleMap]);

	useEffect(() => {
		navigation.setParams({ isParking: isParkingMap });
	}, [isParkingMap]);

	if (isParkingMap) {
		return (
			<View style={styles.container}>
				<ParkingsMap />
			</View>
		);
	} else {
		return (
			<View style={styles.container}>
				<BuildingsMap />
			</View>
		);
	}
};

CampusMapScreen.navigationOptions = (navigationData) => {
	return {
		headerTitle: 'Campus Map',
		headerTitleStyle: {
			textAlign: 'center',
		},
		headerLeft: () => (
			<HeaderButtons HeaderButtonComponent={HeaderButton}>
				<Item
					title="Menu"
					iconName="ios-menu"
					onPress={() => {
						navigationData.navigation.toggleDrawer();
					}}
				/>
			</HeaderButtons>
		),
		headerRight: () => (
			<HeaderButtons HeaderButtonComponent={HeaderButton}>
				<Item
					title="Menu"
					iconName={
						navigationData.navigation.getParam('isParking')
							? 'ios-business'
							: 'ios-car'
					}
					onPress={navigationData.navigation.getParam('changeMap')}
				/>
			</HeaderButtons>
		),
	};
};

const styles = StyleSheet.create({
	container: {
		flex: 1,
		backgroundColor: '#fff',
		alignItems: 'center',
		justifyContent: 'center',
	},
});

export default CampusMapScreen;
