import React from 'react';
import { View, StyleSheet, ScrollView, Image } from 'react-native';
import Paragraph from '../../components/Paragraph';
import StrongText from '../../components/StrongText';
import Title from '../../components/Title';
import ListItem from '../../components/ListItem';
import AccentParagraph from '../../components/AccentParagraph';
import DefaultText from '../../components/DefaultText';
import TextLink from '../../components/TextLink';

const InstituteScreen = (props) => {
	return (
		<ScrollView>
			<View>
				<Image
					style={styles.image}
					resizeMode="cover"
					source={require('../../assets/images/faculties/iec-cover.jpg')}
				/>
			</View>
			<View style={styles.textContainer}>
				<Paragraph>
					The only university institute at CZU is a pedagogical and
					scientific research worksite. It offers studies in
					programmes focused on obtaining pedagogical education and
					counselling in education. It has a richly developed
					cooperation with foreign universities and organizations
					dealing with the training of teachers and professional
					advisors.
				</Paragraph>
				<Paragraph>
					Its uniqueness is its location on the edge of the Chuchelský
					háj, a protected nature reserve in Malá Chuchle, on a
					pleasant premises equipped with modern facilities. Teaching
					takes place both at the university campus in Suchdol and on
					the IEC premises.
				</Paragraph>
				<View>
					<ListItem>
						More than 300 students are studying at the institute,
						and about 20 employees work here.
					</ListItem>
					<ListItem>
						The institute consists of 3 departments and 3
						workplaces.
					</ListItem>
					<ListItem>Director: Ing. Karel Němejc</ListItem>
				</View>
				<AccentParagraph backgroundColor="#663414">
					<Title style={styles.whiteText}>Contacts</Title>
					<View>
						<ListItem
							style={styles.whiteText}
							pointerColor="white"
							pointerIcon="ios-earth"
						>
							<TextLink
								style={styles.accentLink}
								linkTo="https://www.ivp.czu.cz/en"
							>
								ivp.czu.cz
							</TextLink>
						</ListItem>
						<ListItem
							style={styles.whiteText}
							pointerColor="white"
							pointerIcon="ios-logo-linkedin"
						>
							<TextLink
								style={styles.accentLink}
								linkTo="https://linkedin.com/school/czu-ivp"
							>
								linkedin.com/school/czu-ivp
							</TextLink>
						</ListItem>
						<ListItem
							style={styles.whiteText}
							pointerColor="white"
							pointerIcon="ios-logo-facebook"
						>
							<TextLink
								style={styles.accentLink}
								linkTo="https://facebook.com/ivp.czu.cz"
							>
								facebook.com/ivp.czu.cz
							</TextLink>
						</ListItem>
						<ListItem
							style={styles.whiteText}
							pointerColor="white"
							pointerIcon="ios-location"
						>
							<TextLink
								style={styles.accentLink}
								linkTo="https://www.google.com/maps/place/V+L%C3%A1zn%C3%ADch+3,+159+00+Velk%C3%A1+Chuchle-Barrandov/@50.0246381,14.3897642,17z/data=!3m1!4b1!4m5!3m4!1s0x470b9699774d5f9f:0x5824761da21f1d9d!8m2!3d50.0246381!4d14.3919529"
							>
								V Lázních 3, 159 00 Praha 5 – Malá Chuchle
							</TextLink>
						</ListItem>
					</View>
				</AccentParagraph>
				<Title>Study Administration Office</Title>
				<StrongText>Head of the Study Administration Office</StrongText>
				<View>
					<ListItem pointerIcon="ios-person">
						Ing. Tereza Popovičová
					</ListItem>
					<ListItem pointerIcon="ios-call">
						<TextLink
							style={styles.normalLink}
							linkTo="tel:+420 224 386 001"
						>
							+420 224 386 001
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-mail">
						<TextLink
							style={styles.normalLink}
							linkTo="mailto:popovicova@ivp.czu.cz"
						>
							popovicova@ivp.czu.cz
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-location">room IVP/22</ListItem>
				</View>
				<StrongText>
					Deputy Director and International Students‘ Coordinator
				</StrongText>
				<View>
					<ListItem pointerIcon="ios-person">
						Ing. Barbora Jordánová
					</ListItem>
					<ListItem pointerIcon="ios-call">
						<TextLink
							style={styles.normalLink}
							linkTo="tel:+420 224 386 006"
						>
							+420 224 386 006
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-mail">
						<TextLink
							style={styles.normalLink}
							linkTo="mailto:jordanova@ivp.czu.cz"
						>
							jordanova@ivp.czu.cz
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-location">room IVP/78</ListItem>
				</View>
				<AccentParagraph backgroundColor="#663414">
					<StrongText style={styles.whiteText}>
						How to get to Malá Chuchle by public transport?
					</StrongText>
					<DefaultText style={styles.whiteText}>
						Take metro B or tram no. 4, 5, 12, 20 to Smíchovské
						nádraží station, then buses no. 129, 172, 241, 244, 318
						to the Malá Chuchle stop (second stop - stop at the
						sign), then according to the direction signs.
					</DefaultText>
				</AccentParagraph>
			</View>
		</ScrollView>
	);
};

InstituteScreen.navigationOptions = (navigationData) => {
	return {
		headerTitle: 'Institute of Education and Communication',
		headerStyle: {
			backgroundColor: '#663414',
		},
	};
};

const styles = StyleSheet.create({
	image: {
		width: '100%',
		height: 100,
	},
	textContainer: {
		paddingVertical: 10,
		paddingHorizontal: 20,
	},
	whiteText: {
		color: 'white',
		marginBottom: 5,
	},
	accentLink: {
		color: 'white',
		fontFamily: 'open-sans',
	},
	normalLink: {
		color: 'black',
		fontFamily: 'open-sans',
	},
});

export default InstituteScreen;
